Managing substitutions
======================

AlekSIS has basic support for managing substitutions and cancellations.

In the mnue under `Timetable → Daily lessons`, a list of all lessons taking
place on a day can be found.

.. image:: ../_static/daily_lessons.png
  :width: 600
  :alt: Daily lessons

The list allows editing a substitution for each lesson.

.. image:: ../_static/substitution_edit.png
  :width: 600
  :alt: Edit a substitution

When editing a substitution, the week, date, and lesson is pre-filled.
The fields for `teacher`, `room`, and `subject` allow replacing
the respective information for the selected lesson.

It should be noted that support for editing substitutions is currently
very basic, and the feature should not be used when substitution data
is imported from an external source.
